@@ -22,6 +22,8 @@
 
 #include "kleopageconfigdialog.h"
 
+#include <kcmutils_version.h>
+
 #include <QDesktopServices>
 #include <QDialogButtonBox>
 #include <QProcess>
@@ -191,11 +193,19 @@ void KleoPageConfigDialog::slotHelpClicked()
 void KleoPageConfigDialog::addModule(const QString &name, const QString &docPath, const QString &icon, KCModule *module)
 {
     mModules << module;
-
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     KPageWidgetItem *item = addPage(module, name);
+#else
+    KPageWidgetItem *item = addPage(module->widget(), name);
+#endif
     item->setIcon(QIcon::fromTheme(icon));
-
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     connect(module, SIGNAL(changed(bool)), this, SLOT(moduleChanged(bool)));
+#else
+    connect(module, &KCModule::needsSaveChanged, this, [this, module]() {
+        moduleChanged(module->needsSave());
+    });
+#endif
 
     mHelpUrls.insert(name, docPath);
 }
