@@ -19,7 +19,6 @@
 #include <Libkleo/KeyCache>
 #include <Libkleo/Formatting>
 
-#include <kmime/kmime_header_parsing.h>
 
 #include <gpgme++/key.h>
 
@@ -621,7 +620,8 @@ void ResolveRecipientsPage::setRecipients(const std::vector<Mailbox> &recipients
 std::vector<Key> ResolveRecipientsPage::resolvedCertificates() const
 {
     std::vector<Key> certs;
-    Q_FOREACH (const QString &i, d->m_listWidget->identifiers()) {
+    const QStringList identifiers = d->m_listWidget->identifiers();
+    for (const QString &i : identifiers) {
         const GpgME::Key cert = d->m_listWidget->selectedCertificate(i);
         if (!cert.isNull()) {
             certs.push_back(cert);
@@ -637,7 +637,8 @@ void ResolveRecipientsPage::Private::selectionChanged()
 
 void ResolveRecipientsPage::Private::removeSelectedEntries()
 {
-    Q_FOREACH (const QString &i, m_listWidget->selectedEntries()) {
+    const auto selectedEntries{m_listWidget->selectedEntries()};
+    for (const QString &i : selectedEntries) {
         m_listWidget->removeEntry(i);
     }
     Q_EMIT q->completeChanged();
@@ -670,7 +671,8 @@ void ResolveRecipientsPage::Private::writeSelectedCertificatesToPreferences()
         return;
     }
 
-    Q_FOREACH (const QString &i, m_listWidget->identifiers()) {
+    const auto identifiers{m_listWidget->identifiers()};
+    for (const QString &i : identifiers) {
         const Mailbox mbox = m_listWidget->mailbox(i);
         if (!mbox.hasAddress()) {
             continue;
