@@ -7,8 +7,7 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef __LIBKLEOPATRACLIENT_CORE_SIGNENCRYPTFILESCOMMAND_H__
-#define __LIBKLEOPATRACLIENT_CORE_SIGNENCRYPTFILESCOMMAND_H__
+#pragma once
 
 #include <libkleopatraclient/core/command.h>
 
@@ -20,7 +19,7 @@ class KLEOPATRACLIENTCORE_EXPORT SignEncryptFilesCommand : public Command
     Q_OBJECT
 public:
     explicit SignEncryptFilesCommand(QObject *parent = nullptr);
-    ~SignEncryptFilesCommand();
+    ~SignEncryptFilesCommand() override;
 
     // Inputs
 
@@ -32,4 +31,3 @@ public:
 
 }
 
-#endif /* __LIBKLEOPATRACLIENT_CORE_SIGNENCRYPTFILESCOMMAND_H__ */
