@@ -11,10 +11,12 @@
 #include "keys.h"
 
 #include <kleopatra_debug.h>
+#include <settings.h>
 
 #include <Libkleo/Algorithm>
 #include <Libkleo/KeyCache>
 
+#include <QDate>
 
 // needed for GPGME_VERSION_NUMBER
 #include <gpgme.h>
@@ -160,3 +162,18 @@ bool Kleo::userIDsAreEqual(const GpgME::UserID &lhs, const GpgME::UserID &rhs)
             && qstrcmp(lhs.id(), rhs.id()) == 0
             && creationDate(lhs) == creationDate(rhs));
 }
+
+QDate Kleo::defaultExpirationDate(Kleo::ExpirationOnUnlimitedValidity onUnlimitedValidity)
+{
+    QDate expirationDate;
+
+    const auto settings = Kleo::Settings{};
+    const auto defaultExpirationInDays = settings.validityPeriodInDays();
+    if (defaultExpirationInDays > 0) {
+        expirationDate = QDate::currentDate().addDays(defaultExpirationInDays);
+    } else if (defaultExpirationInDays < 0 || onUnlimitedValidity == ExpirationOnUnlimitedValidity::InternalDefaultExpiration) {
+        expirationDate = QDate::currentDate().addYears(3);
+    }
+
+    return expirationDate;
+}
