@@ -1,5 +1,4 @@
-#ifndef KUNIQUESERVICE_H
-#define KUNIQUESERVICE_H
+#pragma once
 /*
     kuniqueservice.h
 
@@ -43,7 +42,7 @@ public:
      * Default constructor
      */
     KUniqueService();
-    ~KUniqueService();
+    ~KUniqueService() override;
 
 public Q_SLOTS:
     /**
@@ -67,4 +66,3 @@ private:
     Q_DECLARE_PRIVATE(KUniqueService)
     KUniqueServicePrivate *d_ptr;
 };
-#endif // KUNIQUESERVICE_H
