@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_UTILS_USERINFO_WIN_P_H__
-#define __KLEOPATRA_UTILS_USERINFO_WIN_P_H__
+#pragma once
 
 #include <windows.h>
 #define SECURITY_WIN32
@@ -20,4 +19,3 @@ QString win_get_user_name(EXTENDED_NAME_FORMAT what);
 
 bool win_user_is_elevated();
 
-#endif // __KLEOPATRA_UTILS_USERINFO_WIN_P_H__
